@@ -121,7 +121,7 @@ pilot_connect (GPilotDevice *device,int *error)
 	struct pi_sockaddr addr;
 	int sd, listen_sd, pf;
 	int ret;
-    
+	
 	if (device->type != PILOT_DEVICE_NETWORK) {
 		pilot_set_baud_rate (device);
 	}
@@ -191,7 +191,7 @@ pilot_connect (GPilotDevice *device,int *error)
 		pi_close(listen_sd);
 		return 0;
 	}
-
+		
 	if (error)
 		*error = 0;
 	pi_close(listen_sd);
@@ -629,7 +629,8 @@ sync_device (GPilotDevice *device, GPilotContext *context)
 	int pfd;
 	int connect_error;
 	struct PilotUser pu;
-
+	struct SysInfo ps;
+	
 	g_assert (context != NULL);
 	g_return_val_if_fail (device != NULL, FALSE);
 
@@ -637,10 +638,16 @@ sync_device (GPilotDevice *device, GPilotContext *context)
 	pfd = pilot_connect (device,&connect_error);
 
 	if (!connect_error) {
+		/* connect succeeded, try to read the systeminfo */
+		if (dlp_ReadSysInfo (pfd, &ps) < 0) {
+			/* no ? drop connection then */
+			g_warning (_("An error occured while getting the pilot's system data"));
+
 		/* connect succeeded, try to read the userinfo */
-		if (dlp_ReadUserInfo (pfd,&pu) < 0) {
+		} else if (dlp_ReadUserInfo (pfd,&pu) < 0) {
 			/* no ? drop connection then */
 			g_warning (_("An error occured while getting the pilot's user data"));
+
 		} else {
 	
 			/* If there are cradle specific events, handle them and stop */
@@ -843,7 +850,7 @@ static gboolean product_net[] =
 	FALSE,
 	TRUE,
 	TRUE,
-	NULL
+	-1
 };
 
 
